@@ -19,7 +19,7 @@ class TextBitableFieldType(BaseBitableFieldType):
     def escape_out(self, value: str | None) -> str | None:
         if value is None:
             return None
-        if isinstance(value, str) and value:
+        if isinstance(value, str):
             return value
         raise ValueError(
             f"TextBitableFieldType escape_out value must be str, but got type: '{type(value)}', value: '{value}'"
@@ -28,12 +28,12 @@ class TextBitableFieldType(BaseBitableFieldType):
     def escape_in(self, value: Any | None) -> str | None:
         if value is None:
             return None
-        if isinstance(value, str) and value:
+        if isinstance(value, str):
             return value
         if isinstance(value, list) and len(value) > 0:
             for item in value:
                 if isinstance(item, dict) and "text" in item:
-                    return item.get("text")
+                    return item.get("text", None)
         raise ValueError(
             f"TextBitableFieldType escape_in value must be str or list, but got type: '{type(value)}', value: '{value}'"
         )
@@ -43,8 +43,11 @@ class UrlBitableFieldType(BaseBitableFieldType):
     def escape_out(self, value: str | None) -> Dict[str, str] | None:
         if value is None:
             return None
-        if isinstance(value, str) and value:
-            return {"text": str(value), "link": str(value)}
+        if isinstance(value, str):
+            if value:
+                return {"text": str(value), "link": str(value)}
+            else:
+                return None
         raise ValueError(
             f"UrlBitableFieldType escape_out value must be str, but got type: '{type(value)}', value: '{value}'"
         )
@@ -52,10 +55,10 @@ class UrlBitableFieldType(BaseBitableFieldType):
     def escape_in(self, value: Any | None) -> str | None:
         if value is None:
             return None
-        if isinstance(value, str) and value:
+        if isinstance(value, str):
             return value
         if isinstance(value, dict) and "link" in value:
-            return value.get("link")
+            return value.get("link", None)
         raise ValueError(
             f"UrlBitableFieldType escape_in value must be str or dict, but got type: '{type(value)}', value: '{value}'"
         )
@@ -65,8 +68,11 @@ class UserBitableFieldType(BaseBitableFieldType):
     def escape_out(self, value: str | None) -> List[Dict[str, str]] | None:
         if value is None:
             return None
-        if isinstance(value, str) and value:
-            return [{"id": str(value)}]
+        if isinstance(value, str):
+            if value:
+                return [{"id": str(value)}]
+            else:
+                return None
         raise ValueError(
             f"UserBitableFieldType escape_out value must be str, but got type: '{type(value)}', value: '{value}'"
         )
@@ -77,7 +83,7 @@ class UserBitableFieldType(BaseBitableFieldType):
         if isinstance(value, list) and len(value) > 0:
             for item in value:
                 if isinstance(item, dict) and "id" in item:
-                    return item.get("id")
+                    return item.get("id", None)
         raise ValueError(
             f"UserBitableFieldType escape_in value must be list, but got type: '{type(value)}', value: '{value}'"
         )
@@ -102,8 +108,11 @@ class DateTimeBitableFieldType(BaseBitableFieldType):
     def escape_in(self, value: Any | None) -> datetime | None:
         if value is None:
             return None
-        if isinstance(value, int) and value > 0:
-            return datetime.fromtimestamp(value / 1000)
+        if isinstance(value, int):
+            if value > 0:
+                return datetime.fromtimestamp(value / 1000)
+            else:
+                return None
         raise ValueError(
             f"DateTimeBitableFieldType escape_in value must be int, but got type: '{type(value)}', value: '{value}'"
         )
@@ -113,7 +122,7 @@ class SingleSelectBitableFieldType(BaseBitableFieldType):
     def escape_out(self, value: str | None) -> str | None:
         if value is None:
             return None
-        if isinstance(value, str) and value:
+        if isinstance(value, str):
             return value
         raise ValueError(
             f"SingleSelectBitableFieldType escape_out value must be str, but got type: '{type(value)}', value: '{value}'"
@@ -122,7 +131,7 @@ class SingleSelectBitableFieldType(BaseBitableFieldType):
     def escape_in(self, value: Any | None) -> str | None:
         if value is None:
             return None
-        if isinstance(value, str) and value:
+        if isinstance(value, str):
             return value
         raise ValueError(
             f"SingleSelectBitableFieldType escape_in value must be str, but got type: '{type(value)}', value: '{value}'"
