@@ -14,6 +14,7 @@ from lark_oapi.api.bitable.v1 import (
 from typing import Dict, Any, Optional
 
 from ..lark_client import client
+from . import USER_ID_TYPE
 
 
 def create_bitable_record(
@@ -40,7 +41,7 @@ def create_bitable_record(
         CreateAppTableRecordRequest.builder()
         .app_token(app_token)
         .table_id(table_id)
-        .user_id_type("user_id")
+        .user_id_type(USER_ID_TYPE)
         .request_body(AppTableRecord.builder().fields(fields).build())
         .build()
     )
