@@ -14,19 +14,20 @@ from lark_oapi.api.bitable.v1 import (
     Condition,
     Sort,
 )
-from typing import Dict, Any, Optional, List, Tuple, Union
+from typing import Dict, Any, List, Tuple
 from ..lark_client import client
+from . import USER_ID_TYPE
 
 
 def search_bitable_records(
     app_token: str,
     table_id: str,
     view_id: str,
-    field_names: Optional[List[str]] = None,
-    conjunction: Optional[str] = None,
-    conditions: Optional[List[Tuple[str, str, List[str]]]] = None,
-    sorts: Optional[List[Tuple[str, bool]]] = None,
-    page_token: Optional[str] = None,
+    field_names: List[str] | None = None,
+    conjunction: str | None = None,
+    conditions: List[Tuple[str, str, List[str]]] | None = None,
+    sorts: List[Tuple[str, bool]] | None = None,
+    page_token: str | None = None,
     page_size: int = 20,
 ) -> SearchAppTableRecordResponseBody:
     """
@@ -41,7 +42,7 @@ def search_bitable_records(
         conditions: 筛选条件列表，每个条件为(字段名, 操作符, 值列表)的三元组，默认为None
             支持的操作符：
             - is：等于
-            - isNot：不等于（不支持日期字段）
+            - isNot：不等于（不支持日期字段，了解如何查询日期字段，参考日期字段填写说明）
             - contains：包含（不支持日期字段）
             - doesNotContain：不包含（不支持日期字段）
             - isEmpty：为空
@@ -50,6 +51,8 @@ def search_bitable_records(
             - isGreaterEqual：大于等于（不支持日期字段）
             - isLess：小于
             - isLessEqual：小于等于（不支持日期字段）
+            - like：LIKE 运算符。暂未支持
+            - in：IN 运算符。暂未支持
         sorts: 排序条件列表，每个条件为(字段名, 是否降序)的二元组，默认为None
         page_token: 分页标记，默认为None
         page_size: 每页记录数，默认为20
@@ -65,7 +68,7 @@ def search_bitable_records(
         SearchAppTableRecordRequest.builder()
         .app_token(app_token)
         .table_id(table_id)
-        .user_id_type("user_id")
+        .user_id_type(USER_ID_TYPE)
         .page_size(page_size)
     )
 
@@ -111,6 +114,8 @@ def search_bitable_records(
 
         request_body_builder.filter(filter_info)
 
+        request_body_builder.automatic_fields(True)
+
     # 完成请求构建
     request = request_builder.request_body(request_body_builder.build()).build()
 
